@@ -11,7 +11,11 @@ assert <- function(bool) {
   if (!bool) stop(bool, " is not TRUE")
 }
 assert_equal <- function(expected, actual) {
-  if (any(expected != actual)) stop("Expected <", expected, ">, got <", actual, ">")
+  if (any(!identical(expected, actual))) {
+    estr <- paste(capture.output(str(expected)), collapse="\n    ");
+    astr <- paste(capture.output(str(actual)), collapse="\n    ");
+    stop(paste("", "Expected:", estr, "got:", astr, sep="\n  "))
+  }
 }
 assert_nan <- function(value) {
   if (!is.nan(value)) stop(value, " is not NaN")
